==> ldap-account-manager_8.0.1.orig.tar.bz2: ldap-account-manager-8.0.1/templates/lib/extra/ckeditor/plugins/table/lang/ku.js <==
/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'ku', {
	border: 'گەورەیی پەراوێز',
	caption: 'سەردێڕ',
	cell: {
		menu: 'خانه',
		insertBefore: 'دانانی خانه لەپێش',
		insertAfter: 'دانانی خانه لەپاش',
		deleteCell: 'سڕینەوەی خانه',
		merge: 'تێکەڵکردنی خانە',
		mergeRight: 'تێکەڵکردنی لەگەڵ ڕاست',
		mergeDown: 'تێکەڵکردنی لەگەڵ خوارەوە',
		splitHorizontal: 'دابەشکردنی خانەی ئاسۆیی',
		splitVertical: 'دابەشکردنی خانەی ئەستونی',
		title: 'خاسیەتی خانه',
		cellType: 'جۆری خانه',
		rowSpan: 'ماوەی نێوان ڕیز',
		colSpan: 'بستی ئەستونی',
		wordWrap: 'پێچانەوەی وشە',
		hAlign: 'ڕیزکردنی ئاسۆیی',
		vAlign: 'ڕیزکردنی ئەستونی',
		alignBaseline: 'هێڵەبنەڕەت',
		bgColor: 'ڕەنگی پاشبنەما',
		borderColor: 'ڕەنگی پەراوێز',
		data: 'داتا',
		header: 'سەرپەڕه',
		yes: 'بەڵێ',
		no: 'نەخێر',
		invalidWidth: 'پانی خانه دەبێت بەتەواوی ژماره بێت.',
		invalidHeight: 'درێژی خانه بەتەواوی دەبێت ژمارە بێت.',
		invalidRowSpan: 'ماوەی نێوان ڕیز بەتەواوی دەبێت ژمارە بێت.',
		invalidColSpan: 'ماوەی نێوان ئەستونی بەتەواوی دەبێت ژمارە بێت.',
		chooseColor: 'هەڵبژێرە'
	},
	cellPad: 'بۆشایی ناوپۆش',
	cellSpace: 'بۆشایی خانه',
	column: {
		menu: 'ئەستون',
		insertBefore: 'دانانی ئەستون لەپێش',
		insertAfter: 'دانانی ئەستوون لەپاش',
		deleteColumn: 'سڕینەوەی ئەستوون'
	},
	columns: 'ستوونەکان',
	deleteTable: 'سڕینەوەی خشتە',
	headers: 'سەرپەڕه',
	headersBoth: 'هەردووك',
	headersColumn: 'یەکەم ئەستوون',
	headersNone: 'هیچ',
	headersRow: 'یەکەم ڕیز',
	heightUnit: 'یەکەی بەرز',
	invalidBorder: 'ژمارەی پەراوێز دەبێت تەنها ژماره بێت.',
	invalidCellPadding: 'ناوپۆشی خانه دەبێت ژمارەکی درووست بێت.',
	invalidCellSpacing: 'بۆشایی خانه دەبێت ژمارەکی درووست بێت.',
	invalidCols: 'ژمارەی ئەستوونی دەبێت گەورەتر بێت لەژمارەی 0.',
	invalidHeight: 'درێژی خشته دهبێت تهنها ژماره بێت.',
	invalidRows: 'ژمارەی ڕیز دەبێت گەورەتر بێت لەژمارەی 0.',
	invalidWidth: 'پانی خشته دەبێت تەنها ژماره بێت.',
	menu: 'خاسیەتی خشتە',
	row: {
		menu: 'ڕیز',
		insertBefore: 'دانانی ڕیز لەپێش',
		insertAfter: 'دانانی ڕیز لەپاش',
		deleteRow: 'سڕینەوەی ڕیز'
	},
	rows: 'ڕیز',
	summary: 'کورتە',
	title: 'خاسیەتی خشتە',
	toolbar: 'خشتە',
	widthPc: 'لەسەدا',
	widthPx: 'وێنەخاڵ - پیکسل',
	widthUnit: 'پانی یەکە'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/table/lang/ku.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'table', 'ku', {
	border: 'گەورەیی پەراوێز',
	caption: 'سەردێڕ',
	cell: {
		menu: 'خانه',
		insertBefore: 'دانانی خانه لەپێش',
		insertAfter: 'دانانی خانه لەپاش',
		deleteCell: 'سڕینەوەی خانه',
		merge: 'تێکەڵکردنی خانە',
		mergeRight: 'تێکەڵکردنی لەگەڵ ڕاست',
		mergeDown: 'تێکەڵکردنی لەگەڵ خوارەوە',
		splitHorizontal: 'دابەشکردنی خانەی ئاسۆیی',
		splitVertical: 'دابەشکردنی خانەی ئەستونی',
		title: 'خاسیەتی خانه',
		cellType: 'جۆری خانه',
		rowSpan: 'ماوەی نێوان ڕیز',
		colSpan: 'بستی ئەستونی',
		wordWrap: 'پێچانەوەی وشە',
		hAlign: 'ڕیزکردنی ئاسۆیی',
		vAlign: 'ڕیزکردنی ئەستونی',
		alignBaseline: 'هێڵەبنەڕەت',
		bgColor: 'ڕەنگی پاشبنەما',
		borderColor: 'ڕەنگی پەراوێز',
		data: 'داتا',
		header: 'سەرپەڕه',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'بەڵێ',
		no: 'نەخێر',
		invalidWidth: 'پانی خانه دەبێت بەتەواوی ژماره بێت.',
		invalidHeight: 'درێژی خانه بەتەواوی دەبێت ژمارە بێت.',
		invalidRowSpan: 'ماوەی نێوان ڕیز بەتەواوی دەبێت ژمارە بێت.',
		invalidColSpan: 'ماوەی نێوان ئەستونی بەتەواوی دەبێت ژمارە بێت.',
		chooseColor: 'هەڵبژێرە'
	},
	cellPad: 'بۆشایی ناوپۆش',
	cellSpace: 'بۆشایی خانه',
	column: {
		menu: 'ئەستون',
		insertBefore: 'دانانی ئەستون لەپێش',
		insertAfter: 'دانانی ئەستوون لەپاش',
		deleteColumn: 'سڕینەوەی ئەستوون'
	},
	columns: 'ستوونەکان',
	deleteTable: 'سڕینەوەی خشتە',
	headers: 'سەرپەڕه',
	headersBoth: 'هەردووك',
	headersColumn: 'یەکەم ئەستوون',
	headersNone: 'هیچ',
	headersRow: 'یەکەم ڕیز',
	heightUnit: 'یەکەی بەرز',
	invalidBorder: 'ژمارەی پەراوێز دەبێت تەنها ژماره بێت.',
	invalidCellPadding: 'ناوپۆشی خانه دەبێت ژمارەکی درووست بێت.',
	invalidCellSpacing: 'بۆشایی خانه دەبێت ژمارەکی درووست بێت.',
	invalidCols: 'ژمارەی ئەستوونی دەبێت گەورەتر بێت لەژمارەی 0.',
	invalidHeight: 'درێژی خشته دهبێت تهنها ژماره بێت.',
	invalidRows: 'ژمارەی ڕیز دەبێت گەورەتر بێت لەژمارەی 0.',
	invalidWidth: 'پانی خشته دەبێت تەنها ژماره بێت.',
	menu: 'خاسیەتی خشتە',
	row: {
		menu: 'ڕیز',
		insertBefore: 'دانانی ڕیز لەپێش',
		insertAfter: 'دانانی ڕیز لەپاش',
		deleteRow: 'سڕینەوەی ڕیز'
	},
	rows: 'ڕیز',
	summary: 'کورتە',
	title: 'خاسیەتی خشتە',
	toolbar: 'خشتە',
	widthPc: 'لەسەدا',
	widthPx: 'وێنەخاڵ - پیکسل',
	widthUnit: 'پانی یەکە'
} );
